@@ -221,9 +221,9 @@ class LogicQuBit(Qubits, Gates, Circuit):
         self.setMeasuredValues(result)
         return result
 
-    def Measure(self, target, first_lsb = False):  # ex: medir 3 qubits de 5: 2,1,4 do estado "010" -> M010 = |1><1| x |0><0| x 1 x |0><0| x 1
+    def Measure(self, target, fisrt_msb = False):  # ex: medir 3 qubits de 5: 2,1,4 do estado "010" -> M010 = |1><1| x |0><0| x 1 x |0><0| x 1
         target = self.qubitsToList(target)
-        if(not first_lsb):  # first_lsb = True -> o primeiro da lista será o menos significativo
+        if(fisrt_msb):  # se fisrt_msb=True -> o primeiro da lista será o mais significativo
             target.reverse()
         self.setMeasuredQubits(target)
         self.addOp("Measure", target)
